<%include file="/pageheader.html"/> <% from kaithem.src import unitsofmeasure,util,directories import os,urllib def size(f): try: return unitsofmeasure.si_format_number(os.path.getsize(os.path.join(dir,f)),1) except Exception as e: return str(e) %>

# File Manager

Up One Level

    ${dir|h}

Upload

Unpacking puts all zip contents into the current dir, without creating a new subdir "foo" in the zip becomes "DIR/foo". If a destination file exists, it is overwritten.

Upload File:

Upload zip and unpack:

Path | Size | Action
--- | --- | ---
%for i in sorted(os.listdir(dir)):
${i+("/" if os.path.isdir(os.path.join(dir,i)) else '')|h} | ${size(i)}B\ | Delete %if i.endswith("m3u8"): Play in browser %endif %if callback: Choose %endif
%endfor

<%include file="/pagefooter.html"/>